summaryrefslogtreecommitdiff
path: root/classes
diff options
context:
space:
mode:
authorZach Copley <zach@status.net>2010-02-22 01:21:34 -0800
committerZach Copley <zach@status.net>2010-02-22 01:21:34 -0800
commit47300a2ae9a51108fbf59a57cf5ab6e8867b54a6 (patch)
treea3f6f6100deb25e8a6ae35aa2130a3be0c310201 /classes
parentca2a88545d353f0e887f48fe0e3bd43b505031ca (diff)
Upgrade profile-based activity noun to have more complete set of
profile fields
Diffstat (limited to 'classes')
-rw-r--r--classes/Profile.php45
1 files changed, 43 insertions, 2 deletions
diff --git a/classes/Profile.php b/classes/Profile.php
index 6b396c8c3..4f67fc0bc 100644
--- a/classes/Profile.php
+++ b/classes/Profile.php
@@ -792,9 +792,11 @@ class Profile extends Memcached_DataObject
* Returns an XML string fragment with profile information as an
* Activity Streams noun object with the given element type.
*
* Assumes that 'activity' namespace has been previously defined.
*
* @param string $element one of 'actor', 'subject', 'object', 'target'
+ *
* @return string
*/
function asActivityNoun($element)
@@ -811,9 +813,46 @@ class Profile extends Memcached_DataObject
'id',
null,
$this->getUri()
- );
+ );
+
+ // title should contain fullname
$xs->element('title', null, $this->getBestName());
+ // Portable Contacts stuff
+
+ if (isset($this->bio)) {
+
+ // XXX: Possible to use OpenSocial's aboutMe?
+
+ $xs->element('poco:note', null, $this->bio);
+ }
+
+ if (isset($this->homepage)) {
+
+ $xs->elementStart('poco:urls');
+ $xs->element('poco:value', null, $this->homepage);
+ $xs->element('poco:type', null, 'homepage');
+ $xs->element('poco:primary', null, 'true');
+ $xs->elementEnd('poco:urls');
+ }
+
+ if (isset($this->location)) {
+ $xs->elementStart('poco:address');
+ $xs->element('poco:formatted', null, $this->location);
+ $xs->elementEnd('poco:address');
+ }
+
+ if (isset($this->lat) && isset($this->lon)) {
+ $this->element(
+ 'georss:point',
+ null,
+ (float)$this->lat . ' ' . (float)$this->lon
+ );
+ }
+
+ // XXX: Should we send all avatar sizes we have? I think
+ // cliqset does -Z
+
$avatar = $this->getAvatar(AVATAR_PROFILE_SIZE);
$xs->element(
@@ -829,6 +868,8 @@ class Profile extends Memcached_DataObject
$xs->elementEnd('activity:' . $element);
+ // XXX: Add people tags with <poco:tags> plural?
+
return $xs->getString();
}
@@ -792,9 +792,11 @@ class Profile extends Memcached_DataObject
* Activity Streams noun object with the given element type.
*
- * Assumes that 'activity' namespace has been previously defined.
+ * Assumes that 'activity', 'georss', and 'poco' namespace has been
+ * previously defined.
*
* @param string $element one of 'actor', 'subject', 'object', 'target'